@@ -8,20 +8,18 @@ class QCoreApplication;
 class QObject;
 
 
-class RootNode: public QtNode
+class RootNode: public QObjectNode
 {
 public:
     RootNode(QCoreApplication* application);
 
-    virtual QVariant IntrospectNode() const;
-    virtual qint64 GetObjectId() const;
+    virtual NodeIntrospectionData GetIntrospectionData() const;
 
     void AddChild(QObject* child);
 
     virtual std::string GetName() const;
     virtual std::string GetPath() const;
-    virtual bool MatchProperty(const std::string& name, const std::string& value) const;
-    virtual xpathselect::NodeList Children() const;
+    virtual xpathselect::NodeVector Children() const;
 private:
     QCoreApplication* application_;
     QList<QObject*> children_;
